@@ -4,6 +4,7 @@
  * \date   2022-06-06
  */
 
+#include <unistd.h>
 #include "config.h"
 #include "sysincl.h"
 #include "sys_timex.h"
@@ -86,7 +87,7 @@ int adjtime(const struct timeval *delta, struct timeval *olddelta)
 int settimeofday(const struct timeval *tv, const struct timezone *tz)
 {
   time_t time = tv->tv_sec;
-  printf("%s:%d: time: %llu\n", __func__, __LINE__, time);
   settime(time);
+  sleep(1); // defer potential follow-up clock_gettime call
   return 0;
 }
